# just-func-python
[![Python application](https://github.com/justland/just-func-python/actions/workflows/python-app.yml/badge.svg)](https://github.com/justland/just-func-python/actions/workflows/python-app.yml)

Python implementation of [just-func](https://github.com/justland/just-func).

## Develop

```shell
# install dependencies
pip install -r requirements.txt

# run tests
pytest

# run style guide enforcement
flake8 justfunc
```
